/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.jdbc;

import java.io.*;
import java.sql.*;
import java.text.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* A wrapper for a <code>Connection</code>
* object that is aware it is in an HTTP session.
* This enables it to shut down the connection
* when the session is destroyed.
*/
public class BoundConnection
   implements HttpSessionBindingListener, Serializable
{
   private transient Connection connection;

   /**
   * Creates a new <code>BoundConnection</code> object
   * for the specified connection.
   * @param con the connection
   */
   public BoundConnection(Connection con)
   {
      this.connection = con;
   }

   /**
   * Returns the underlying connection
   */
   public Connection getConnection()
   {
      return connection;
   }

   /**
   * Called when the <code>BoundConnection</code>
   * is stored in an HTTP session
   * @param event the binding event
   */
   public void valueBound(HttpSessionBindingEvent event)
   {
      trace("bound", event);
   }

   /**
   * Called when the <code>BoundConnection</code>
   * is removed from an HTTP session
   * @param event the unbinding event
   */
   public void valueUnbound(HttpSessionBindingEvent event)
   {
      if (connection != null)
         try {
            connection.close();
            connection = null;
         }
         catch (SQLException e) {
            e.printStackTrace();
         }
      trace("unbound", event);
   }

   /**
   * Prints a trace message
   */
   private void trace(String s, HttpSessionBindingEvent event)
   {
      HttpSession session = event.getSession();

      java.util.Date now =
         new java.util.Date(System.currentTimeMillis());
      java.util.Date last =
         new java.util.Date(session.getLastAccessedTime());

      SimpleDateFormat fmt = new SimpleDateFormat("hh:mm:ss");
      StringBuffer sb;

      sb = new StringBuffer();
      sb.append("TRACE: ");
      sb.append(fmt.format(now));
      sb.append(" session ");
      sb.append(session.getId());
      sb.append(" last accessed time ");
      sb.append(fmt.format(last));
      System.err.println(sb.toString());

      sb = new StringBuffer();
      sb.append("TRACE: ");
      sb.append(fmt.format(now));
      sb.append(" session ");
      sb.append(session.getId());
      sb.append(" connection " );
      sb.append(s);
      System.err.println(sb.toString());
   }
}
