/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.sessions;

/**
* Holds the number guesser application state
*/
public class GameState
{
   private int tooLow;
   private int tooHigh;
   private int count;

   /**
   * Initializes the state
   */
   public GameState()
   {
      tooLow = 0;
      tooHigh = 101;
      count = 1;
   }

   /**
   * Returns the greatest integer known to be too low.
   */
   public int getTooLow()
   {
      return tooLow;
   }

   /**
   * Sets the "tooLow" value
   * @param tooLow the tooLow
   */
   public void setTooLow(int tooLow)
   {
      this.tooLow = tooLow;
   }

   /**
   * Returns the least integer known to be too high.
   */
   public int getTooHigh()
   {
      return tooHigh;
   }

   /**
   * Sets the tooHigh
   * @param tooHigh the tooHigh
   */
   public void setTooHigh(int tooHigh)
   {
      this.tooHigh = tooHigh;
   }

   /**
   * Returns the number of guesses so far
   */
   public int getCount()
   {
      return count;
   }

   /**
   * Returns the next guess, which is the average of the
   * too high and too low values.
   */
   public int getNextGuess()
   {
      return (getTooHigh() + getTooLow()) / 2;
   }

   /**
   * Updates the lower bound
   */
   public void guessIsTooLow()
   {
      setTooLow(getNextGuess());
   }

   /**
   * Updates the upper bound
   */
   public void guessIsTooHigh()
   {
      setTooHigh(getNextGuess());
   }

   /**
   * Adds 1 to the count
   */
   public void incrementCount()
   {
      count++;
   }

   /**
   * Returns true if the upper and lower bounds
   * leave no room for further guesses between them.
   * This can only happen if the user gave conflicting
   * information
   */
   public boolean boundsAreTooClose()
   {
      return (getTooHigh() - getTooLow()) <= 1;
   }

   /**
   * Returns a randomly chosen message politely accusing
   * the user of cheating.
   */
   public String getCheaterMessage()
   {
      String[] text = {
         "Are we cheating, perhaps?",
         "Did we forget our number, hmm?",
         "Perhaps we clicked the wrong button?",
         "What happened?",
         "What gives?",
      };
      int r = (int) (Math.random() * text.length);
      String message = text[r];
      return message;
   }
}
