/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/

import java.io.*;
import java.net.*;
import java.util.*;

/**
* An illustration of a thread synchronization problem
*/
public class SynchronizationTest implements Runnable
{
   public static void main(String args[])
   {
      new SynchronizationTest();
   }
   
   /**
   * Creates a new SynchronizationTest object that starts
   * five invoice handling threads.
   */
   public SynchronizationTest()
   {
      Thread[] threads = {
         new Thread(this, "A"),
         new Thread(this, "B"),
         new Thread(this, "C"),
         new Thread(this, "D"),
         new Thread(this, "E"),
      };
      for (int i = 0; i < threads.length; i++)
         threads[i].start();
   }

   /**
   * Simulates handling ten invoices. This method
   * will be run by each of the five threads.
   */
   public void run()
   {
      try {
         for (int i = 0; i < 10; i++) {
            handleInvoice();
            Thread.sleep((long) (Math.random()*500));
         }
      }
      catch (InterruptedException ignore) {
      }
      catch (IOException e) {
         e.printStackTrace();
      }
   }

   /**
   * The invoice handling method (with a subtle bug)
   */
   public void handleInvoice() throws IOException
   {
      Thread t = Thread.currentThread();

      // Get the last used invoice number from invoice.dat

      List lines = new ArrayList();
      BufferedReader in =
         new BufferedReader(
         new FileReader("invoice.dat"));
      int invoiceNumber = 0;
      for (;;) {
         String line = in.readLine();
         if (line == null)
            break;
         if (!line.startsWith("#") && !line.trim().equals("")) {
            invoiceNumber = Integer.parseInt(line);
            break;
         }
         lines.add(line);
      }
      in.close();

      // Add 1 to get the current invoice number

      invoiceNumber++;
      System.out.println
         (t.getName() + " handles invoice " + invoiceNumber);

      // Update the invoice number

      PrintWriter out =
         new PrintWriter(
         new FileWriter("invoice.dat"));
      for (Iterator it = lines.iterator(); it.hasNext(); ) {
         out.println(it.next());
      }
      out.println(invoiceNumber);
      out.flush();
      out.close();
   }
}
