/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/

import java.text.*;
import java.util.*;

/**
* A class that demonstrates simple multithreading
*/
public class ThreadExample1
{
   public static void main(String[] args)
   {
      /**
      * Create, name, and start two counter threads
      */

      Thread t1 = new CounterThread();
      t1.setName("A");
      t1.start();

      Thread t2 = new CounterThread();
      t2.setName("B");
      t2.start();
   }
}

/**
* A thread that counts to eight, waiting
* a random length of time between iterations.
*/
class CounterThread extends Thread
{
   /**
   * Date format used in message. Includes milliseconds.
   */

   public static final SimpleDateFormat FMT
      = new SimpleDateFormat("hh:mm:ss.SSS aa");

   /**
   * Starts the run method in a new thread
   */
   public void start()
   {
      System.out.println("Starting " + getName());
      super.start();
   }

   /**
   * Where the counter loop takes place.
   */
   public void run()
   {
      for (int i = 0; i < 8; i++) {
         try {
            sleep((long) (Math.random() * 500 + 100));
         }
         catch (InterruptedException e) {
            break;
         }
         System.out.println
            (FMT.format(new Date())
            + " Thread " + getName()
            + ": Count = " + i);
      }
      System.out.println("Leaving " + getName());
   }
}
