/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/

import java.text.*;
import java.util.*;

/**
* A class that demonstrates simple multithreading
* using <code>java.util.Timer</code>
*/
public class TimerExample
{
   /**
   * Creates and runs an instance of the timer example.
   */
   public static void main(String[] args)
   {
      new TimerExample().run();
   }

   private Timer timer;
   private int taskCount;

   /**
   * Runs two timer tasks
   */
   public void run()
   {
      // Create a timer to control the timer tasks

      timer = new Timer();

      // Keep track of how many tasks have been
      // created so that we can shut down the
      // timer.

      taskCount = 0;

      // Create two timer tasks and schedule
      // their execution at half-second intervals,
      // delaying the second one's start by 250 ms

      TimerTask t1 = new CounterTimerTask("A", this);
      taskCount++;
      timer.schedule(t1, 0, 500);

      TimerTask t2 = new CounterTimerTask("B", this);
      taskCount++;
      timer.schedule(t2, 250, 500);
   }

   /**
   * Callback method that allows scheduled tasks to
   * notify us when they are done.
   */
   public synchronized void done()
   {
      taskCount--;
      if (taskCount <= 0)
         timer.cancel();
   }
}

/**
* A TimerTask that counts to eight
*/
class CounterTimerTask extends TimerTask
{
   /**
   * Date format used in message. Includes milliseconds.
   */
   public static final SimpleDateFormat FMT
      = new SimpleDateFormat("hh:mm:ss.SSS aa");

   private String name;
   private int counter;
   private TimerExample parent;

   public CounterTimerTask(String name, TimerExample parent)
   {
      this.name = name;
      this.counter = 0;
      this.parent = parent;
   }

   /**
   * Where the counter loop takes place.
   */
   public void run()
   {
      if (counter == 0)
         System.out.println("Starting " + name);

      System.out.println
         (FMT.format(new Date())
         + " Thread " + name
         + ": Count = " + counter);

      counter++;
      if (counter >= 8) {
         System.out.println("Leaving " + name);
         cancel();
         parent.done();
      }
   }
}
