/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.listeners.attributes;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* A session attribute listener that controls the
* starting and stopping of a shared news feed.
* The news server is active only while there are
* one or more sessions using it.
*/
public class NewsController implements HttpSessionAttributeListener
{
   /**
   * Name of attribute that triggers startup and
   * shutdown of news server
   */
   public static final String ATTRIBUTE_NAME
      = "com.jspcr.listeners.attributes.newsfeed";

   /**
   * Number of sessions using the news server
   */
   private int referenceCount = 0;

   // ===========================================
   //    These three methods implement the
   //    HttpSessionAttributeListener interface
   // ===========================================

   /**
   * Called when an attribute has been added to a session. 
   */
   public void attributeAdded(HttpSessionBindingEvent se)
   {
      String name = se.getName();
      if (name.equals(ATTRIBUTE_NAME)) {
         synchronized(this) {
            if (referenceCount == 0) {
               startNewsServer();
            }
            referenceCount++;
         }
      }
   }

   /**
   * Called when an attribute has been replaced in a session. 
   */
   public void attributeReplaced(HttpSessionBindingEvent se)
   {
   } 

   /**
   * Called when an attribute has been removed from a session. 
   */
   public void attributeRemoved(HttpSessionBindingEvent se)
   {
      String name = se.getName();
      if (name.equals(ATTRIBUTE_NAME)) {
         synchronized(this) {
            referenceCount--;
            if (referenceCount == 0) {
               stopNewsServer();
            }
         }
      }
   }

   // ===========================================
   //    Methods controlling the shared
   //    news feed
   // ===========================================

   /**
   * Starts the news server
   */
   public void startNewsServer()
   {
      // ... not shown here
   }

   /**
   * Stops the news server
   */
   public void stopNewsServer()
   {
      // ... not shown here
   }
}
