/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.listeners.currency;

import java.io.*;
import java.net.*;
import java.util.*;

/**
* Downloads currency exchange rates from some source
* and makes them available through method calls.
*/
public class RateCache implements Serializable
{
   /**
   * Map of from/to currency code to their
   * exchange rate.
   */
   private Map rateMap;

   /**
   * Time at which rates were last updated
   */
   private Date lastUpdateTime;

   // ===========================================
   //    Constructor
   // ===========================================

   /**
   * Creates a new RateCache
   */
   public RateCache()
   {
      rateMap = new HashMap();
   }

   // ===========================================
   //    Instance methods
   // ===========================================

   /**
   * Updates the map with the most recent values
   */
   public void refresh()
   {
      // Simulate downloading the rates.  Here we just use
      // random values that fall within a plausible range.
      // A robust implementation would also require
      // synchronization so that rates would not be in an
      // inconsistent state while the refresh is going on.

      rateMap.clear();

      Object[][] rates = {
         {"USD","EUR",new Double(0.95),new Double(1.05)},
         {"USD","GBP",new Double(0.60),new Double(0.80)},
         {"USD","JPY",new Double(99.0),new Double(130.0)},
      };
      for (int i = 0; i < rates.length; i++) {

         String fromCurrency = (String) rates[i][0];
         String toCurrency = (String) rates[i][1];
         String key = fromCurrency + toCurrency;

         double lo = ((Double) rates[i][2]).doubleValue();
         double hi = ((Double) rates[i][3]).doubleValue();
         double range = hi - lo;
         double rate = Math.random() * range + lo;

         rateMap.put(key, new Double(rate));
      }

      // Note the time of last update

      lastUpdateTime = new Date();
   }

   /**
   * Returns the specified rate
   */
   public Double getExchangeRate
      (String fromCurrency, String toCurrency)
   {
      String key = fromCurrency + toCurrency;
      Double rate = (Double) rateMap.get(key);
      return rate;
   }

   /**
   * Returns the time of last update
   */
   public Date getLastUpdateTime()
   {
      return lastUpdateTime;
   }
}
