/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.filters;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* Generic filter that passes requests on to the next resource
* in the filter chain.  Intended as a base class from which
* more useful filters are derived.
*/
public class BaseFilter implements Filter
{
   protected FilterConfig config;

   /**
   * Called when the filter is placed into service.
   * @param config the filter configuration object
   * @exception ServletException if a fatal error occurs
   */
   public void init(FilterConfig config)
      throws ServletException
   {
      this.config = config;
   }

   /**
   * Called when the filter is about to be shut down.
   */
   public void destroy()
   {
   }

   /**
   * Convenience method to write a message to the servlet log
   */
   protected void log(String msg)
   {
      config.getServletContext().log(msg);
   }

   /**
   * Passes the request and response unmodified along the
   * filter chain. Subclasses should override this method
   * to perform any required filtering.
   * @param request the original request object
   * @param response the original response object
   * @exception IOException if an I/O error occurs
   * @exception ServletException if an application error occurs.
   */
   public void doFilter(
         ServletRequest request,
         ServletResponse response,
         FilterChain chain)
      throws IOException, ServletException
   {
      // Pass the request on to the next processor in the
      // filter chain.

      chain.doFilter(request, response);
   }
}
