/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.filters;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* Filter that converts a comma-separated-values stream
* to an HTML table
*/
public class CSVFilter extends BaseFilter
{
   public void doFilter(
         ServletRequest request,
         ServletResponse response,
         FilterChain chain)
      throws IOException, ServletException
   {
      // Create a servlet response wrapper that will
      // buffer the response data so that it can be
      // converted to HTML

      BufferedResponseWrapper wrappedResponse =
         new BufferedResponseWrapper
            (response, config.getServletContext());

      // Pass the request on to the next entry in
      // the filter chain

      chain.doFilter(request, wrappedResponse);

      // After the request is processed, retrieve
      // the output lines from the wrapper object.

      String buffer = wrappedResponse.getBufferAsString();
      BufferedReader in =
         new BufferedReader(new StringReader(buffer));

      int nRows = 0;
      int nCols = 0;

      StringBuffer htmlBuffer = new StringBuffer();

      while (true) {
         String line = in.readLine();
         if (line == null)
            break;
         nRows++;

         // We use a regular expression to split the line
         // along comma boundaries. A robust application
         // would need to take into account commas contained
         // inside quoted strings.

         // NOTE: the String.split(regex) method requires
         // JDK 1.4 or greater

         String[] tokens = line.split(",");

         // When the first row of data is read, count
         // the columns so that we can generate the
         // table header

         if (nRows == 1) {
            nCols = tokens.length;
            htmlBuffer.append("<table");
            htmlBuffer.append(" border='1'");
            htmlBuffer.append(" cellpadding='3'");
            htmlBuffer.append(" cellspacing='0'>\n");
         }

         // Write the table cells

         htmlBuffer.append("<tr>\n");
         int col = 0;
         while ((col < tokens.length) && (col < nCols)) {
            htmlBuffer.append("<td>");
            htmlBuffer.append(tokens[col]);
            htmlBuffer.append("</td>\n");
            col++;
         }
         while (col < nCols) {
            htmlBuffer.append("<td>&nbsp;</td>\n");
            col++;
         }
         htmlBuffer.append("</tr>\n");
      }

      // Close the table

      if (nRows > 0)
         htmlBuffer.append("</table>\n");

      // Use the original response object to send
      // converted results back to the requesting client

      response.setContentType("text/html");
      response.setContentLength(htmlBuffer.length());
      PrintWriter out = response.getWriter();
      out.print(htmlBuffer);
      out.flush();
   }
}
