/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.filters;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* Simple class that illustrates the basic operation of a filter
*/
public class LoggingFilter implements Filter
{
   /**
   * Saved reference to filter configuration
   */
   private FilterConfig config;

   /**
   * Called when filter is initialized
   */
   public void init(FilterConfig config)
      throws ServletException
   {
      this.config = config;
      log("Initialized");
   }

   /**
   * Called when filter is shut down
   */
   public void destroy()
   {
      log("Destroyed");
   }

   /**
   * Called when filter is invoked
   */
   public void doFilter(
         ServletRequest request,
         ServletResponse response,
         FilterChain chain)
      throws IOException, ServletException
   {
      HttpServletRequest httpRequest =
         (HttpServletRequest) request;
      log(httpRequest.getServletPath());
      chain.doFilter(request, response);
   }

   /**
   * Convenience method that writes a message to the servlet log
   */
   public void log(String msg)
   {
      config.getServletContext().log("LoggingFilter: " + msg);
   }
}
