/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.filters;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* Filter that sorts the lines of its response data
*/
public class SortFilter extends BaseFilter
{
   public void doFilter(
         ServletRequest request,
         ServletResponse response,
         FilterChain chain)
      throws IOException, ServletException
   {
      // Create a servlet response wrapper that will
      // buffer the response data so that it can be
      // sorted

      BufferedResponseWrapper wrappedResponse =
         new BufferedResponseWrapper
            (response, config.getServletContext());

      // Pass the request on to the next entry in
      // the filter chain

      chain.doFilter(request, wrappedResponse);

      // After the request is processed, retrieve
      // the output lines from the wrapper object
      // and sort them

      // Split the buffer into a list of individual lines

      BufferedReader in =
         new BufferedReader(
         new StringReader(
         wrappedResponse.getBufferAsString()));

      List list = new ArrayList();

      while (true) {
         String line = in.readLine();
         if (line == null)
            break;
         list.add(line);
      }
      in.close();

      // Use the collections framework to sort the list

      Collections.sort(list);

      // Write the sorted list, using the original response
      // object to send results back to the requesting client

      response.setContentType("text/plain");
      PrintWriter out = response.getWriter();

      for (Iterator it = list.iterator(); it.hasNext(); ) {
         String line = (String) it.next();
         out.println(line);
      }
      out.flush();
   }
}
