/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.el.sessions;

import java.io.Serializable;

/**
* Holds the number guesser application state using the
* following properties:
* <ul>
* <li>lowerLimit - highest value so far known to be too low</li>
* <li>upperLimit - lowest value so far known to be too high</li>
* <li>count - number of guesses so far</li>
* <li>nextGuess - readonly integer property</li>
* <li>userCheating - true if the upper and lower limits
*                    leave no room for further guesses.
*                    This can only happen if the user
*                    is cheating.</li>
* <li>cheaterMessage - returns a randomly chosen message
*                      accusing the user of cheating.</li>
* </ul>
*/
public class GameState implements Serializable
{
   // lowerLimit property

   private int lowerLimit = 0;

   public int getLowerLimit() {
      return lowerLimit;
   }

   public void setLowerLimit(int lowerLimit) {
      this.lowerLimit = lowerLimit;
   }

   // upperLimit property

   private int upperLimit = 101;

   public int getUpperLimit() {
      return upperLimit;
   }

   public void setUpperLimit(int upperLimit) {
      this.upperLimit = upperLimit;
   }

   // count property

   private int count = 1;
   public int getCount() {
      return count;
   }
   public void setCount(int count) {
      this.count = count;
   }

   // nextGuess property

   public int getNextGuess() {
      return (getUpperLimit() + getLowerLimit()) / 2;
   }

   // userCheating property

   public boolean getUserCheating()
   {
      return (getUpperLimit() - getLowerLimit()) <= 1;
   }

   // cheaterMessage

   public String getCheaterMessage()
   {
      String[] text = {
         "Are we cheating, perhaps?",
         "Did we forget our number, hmm?",
         "Perhaps we clicked the wrong button?",
         "What happened?",
         "What gives?",
      };
      int r = (int) (Math.random() * text.length);
      String message = text[r];
      return message;
   }
}
