/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.simpletags;

import java.io.*;
import java.text.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;

/**
* Simple tag handler that calculates the Celsius equivalent
* of a range of Fahrenheit temperatures and invokes a
* JSP fragment to display them.
*/
public class F2CSimpleTag extends SimpleTagSupport
{
   /**
   * Attributes (from, to, by) and their getters
   * and setters
   */
   private int from;
   public int getFrom() { return from; }
   public void setFrom(int from) { this.from = from; }

   private int to;
   public int getTo() { return to; }
   public void setTo(int to) { this.to = to; }

   private int by;
   public int getBy() { return by; }
   public void setBy(int by) { this.by = by; }

   /**
   * Default constructor
   */
   public F2CSimpleTag()
   {
      super();
   }

   /**
   * Processs the tag invocation
   */
   public void doTag() throws JspException, IOException
   {
      DecimalFormat fmt = new DecimalFormat("##0.00");

      for (
         int degrees = getFrom();
         degrees <= getTo();
         degrees += getBy())
      {
         // Calculate the Celsius value

         double c = (degrees - 32) * 5 / 9.0;

         // Create the variables used by the JSP fragment

         JspContext ctx = getJspContext();
         ctx.setAttribute("f", String.valueOf(degrees));
         ctx.setAttribute("c", fmt.format(c));

         // Invoke the fragment

         JspFragment fragment = getJspBody();
         fragment.invoke(null);
      }
   }
}
