<%--
  Copyright (c) 2002 by Phil Hanna
  All rights reserved.
  
  You may study, use, modify, and distribute this
  software for any purpose provided that this
  copyright notice appears in all copies.
  
  This software is provided without warranty
  either expressed or implied.
--%>
<%@ page session="false" %>
<%@ page import="java.io.*" %>
<%@ page import="java.net.*" %>
<%@ page import="java.sql.*" %>
<%@ page import="javax.naming.*" %>
<%@ page import="javax.sql.*" %>
<html>
<head><title>Batch Update Example</title></head>
<body>
<h1>Batch Update Example</h1>
<pre>
<%
   // Get the data source using JNDI

   InitialContext initCtx = new InitialContext();
   Context ctx = (Context) initCtx.lookup("java:comp/env");
   DataSource ds = (DataSource) ctx.lookup("jdbc/LyricNote");

   // Define these objects outside the "try" block so that
   // they can be closed in the "finally" block

   Connection con = null;
   Statement stmt = null;

   try {

      // Get a connection from the data source
      // and a statement from the connection

      con = ds.getConnection();
      stmt = con.createStatement();

      // Clear the over90 table if it exists
      // and create a new one

      stmt.executeUpdate("DROP TABLE IF EXISTS over90");
      stmt.executeUpdate(
         "CREATE TABLE over90 ("
         + "    lastName      CHAR(20),"
         + "    firstName     CHAR(20),"
         + "    age           INTEGER)"
         );

      // Set up for handling all-or-nothing transaction

      con.setAutoCommit(false);

      // Tell the database we're going to use a batch update

      stmt.clearBatch();

      // Read lines from a comma-separated-values file

      URL dataURL = application.getResource
         ("/examples/over90.csv");

      BufferedReader in =
         new BufferedReader(
         new InputStreamReader(
         dataURL.openStream()));

      out.println("Reading lines from " + dataURL);
      out.println();
      int nLines = 0;
      while (true) {
         String line = in.readLine();
         if (line == null)
            break;
         nLines++;
         out.println(nLines + ": " + line);

         // Split the input line into three tokens

         String[] tokens = line.split(",");
         if (tokens.length != 3)
            throw new IOException("Bad input data");

         String lastName = tokens[0];
         String firstName = tokens[1];
         String age = tokens[2];

         // Add an SQL INSERT statement to the batch

         final String QUOTE = "'";

         String insertSQL = "INSERT INTO over90 VALUES ("
            + QUOTE + lastName + QUOTE + ","
            + QUOTE + firstName + QUOTE + ","
            + age + ")" ;

         stmt.addBatch(insertSQL);
      }

      in.close();

      // Now execute the batch

      out.println();
      out.println("Starting batch update");
      int[] rowsInserted = stmt.executeBatch();

      // There should have been one row updated for
      // every statement in the batch

      int n = rowsInserted.length;
      int sum = 0;
      for (int i = 0; i < n; i++)
         sum += rowsInserted[i];

      out.println();
      out.println(n + " rows inserted");

      // If all updates were good, commit the transaction

      if (sum == n) {
         out.println("Committing transaction");
         con.commit();
      }

      // Otherwise, rollback

      else {
         out.println("Rolling back transaction");
         con.rollback();
      }
   }
   finally {

      // Close any open JDBC objects

      if (stmt != null) stmt.close();
      if (con != null) con.close();
   }
%>
</pre>
</body>
</html>
