<%--
  Copyright (c) 2002 by Phil Hanna
  All rights reserved.
  
  You may study, use, modify, and distribute this
  software for any purpose provided that this
  copyright notice appears in all copies.
  
  This software is provided without warranty
  either expressed or implied.
--%>
<%@ page session="false" %>
<%@ page import="java.io.*" %>
<%@ page import="java.net.*" %>
<%@ page import="java.sql.*" %>
<%@ page import="javax.naming.*" %>
<%@ page import="javax.sql.*" %>
<html>
<head><title>Prepared Statement Example</title></head>
<body>
<h1>Prepared Statement Example</h1>
<pre>
<%
   // Get the data source using JNDI

   InitialContext initCtx = new InitialContext();
   Context ctx = (Context) initCtx.lookup("java:comp/env");
   DataSource ds = (DataSource) ctx.lookup("jdbc/LyricNote");

   // Define these objects outside the "try" block so that
   // they can be closed in the "finally" block

   Connection con = null;
   Statement stmt = null;
   PreparedStatement pstmt = null;

   try {

      // Get a connection from the data source
      // and a statement from the connection

      con = ds.getConnection();
      stmt = con.createStatement();

      // Clear the over90 table if it exists
      // and create a new one

      stmt.executeUpdate("DROP TABLE IF EXISTS over90");
      stmt.executeUpdate(
         "CREATE TABLE over90 ("
         + "    lastName      CHAR(20),"
         + "    firstName     CHAR(20),"
         + "    age           INTEGER)"
         );
      stmt.close();
      stmt = null;

      // Prepare a statement that will handle the update

      pstmt = con.prepareStatement
         ("INSERT INTO over90 VALUES(?, ?, ?)");

      // Read lines from a comma-separated-values file

      URL dataURL = application.getResource
         ("/examples/over90.csv");

      BufferedReader in =
         new BufferedReader(
         new InputStreamReader(
         dataURL.openStream()));

      out.println("Reading lines from " + dataURL);
      out.println();
      int nLines = 0;
      int totalRowCount = 0;
      while (true) {
         String line = in.readLine();
         if (line == null)
            break;
         nLines++;
         out.println(nLines + ": " + line);

         // Split the input line into three tokens

         String[] tokens = line.split(",");
         if (tokens.length != 3)
            throw new IOException("Bad input data");

         String lastName = tokens[0];
         String firstName = tokens[1];
         int age = Integer.parseInt(tokens[2]);

         // Set the parameters in the prepared statement

         pstmt.setString(1, lastName);
         pstmt.setString(2, firstName);
         pstmt.setInt(3, age);

         // Insert the row in the table

         int rowCount = pstmt.executeUpdate();
         out.println(rowCount + " record added");
         totalRowCount += rowCount;
      }

      in.close();

      out.println();
      out.println(totalRowCount + " rows inserted");
   }
   finally {

      // Close any open JDBC objects

      if (pstmt != null) pstmt.close();
      if (stmt != null) stmt.close();
      if (con != null) con.close();
   }
%>
</pre>
</body>
</html>
