/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.servlets;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
* Dummy servlet that generates XML input.  This version just
* copies xml from somewhere else.  A real application would
* generate it somehow, possible from interrogating a database.
*/
public class XMLSource extends HttpServlet
{
   /**
   * Handles a GET request
   * @param request the servlet request object
   * @param response the servlet response object
   * @exception ServletException if a servlet exception occurs
   * @exception IOException if an I/O exception occurs
   */
   public void doGet(
         HttpServletRequest request,
         HttpServletResponse response)
      throws ServletException, IOException
   {
      response.setContentType("text/xml");
      PrintWriter out = response.getWriter();

      ServletContext application = getServletContext();
      InputStream stream = application.getResourceAsStream("/examples/instruments.xml");
      if (stream == null)
         throw new ServletException
            ("/examples/instruments.xml not found in this servlet context");
      BufferedReader in = new BufferedReader(new InputStreamReader(stream));
      for (;;) {
         String line = in.readLine();
         if (line == null)
            break;
         out.println(line);
      }
      out.flush();
      in.close();
   }

   /**
   * Handles a POST request
   * @param request the servlet request object
   * @param response the servlet response object
   * @exception ServletException if a servlet exception occurs
   * @exception IOException if an I/O exception occurs
   */
   public void doPost(
         HttpServletRequest request,
         HttpServletResponse response)
      throws ServletException, IOException
   {
      doGet(request, response);
   }
}
