/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.xmlsamples;

import java.io.*;
import java.util.*;

/**
* Default implementation of <code>ProductList</code>
* interface. This serves as a common parent for the
* DOM and SAX versions.
*/
public abstract class AbstractProductList
   implements ProductList
{
   /**
   * The constructed list of products
   */
   private List list;

   /**
   * Hard-coded URL - in a real application, this would be
   * a read/write property
   */
   protected String inputURL =
      "http://localhost/chap16/XMLSource";

   // ===========================================
   //    Public interface - this is what
   //    implements ProductList
   // ===========================================

   /**
   * Returns an iterator over the product list.
   * @exception IOException if an I/O error occurs
   */
   public Iterator iterator() throws IOException
   {
      if (list == null)
         list = loadProductList();

      return list.iterator();
   }

   // ===========================================
   //    Abstract methods - must be implemented
   //    by subclasses
   // ===========================================

   /**
   * Loads the product list from the input URL.
   * @exception IOException if an I/O error occurs
   */
   protected abstract List loadProductList() throws IOException;

   // ===========================================
   //    Protected inner class defined here
   //    so that it can be used by subclasses
   // ===========================================

   /**
   * Implementation of the Product interface.
   */
   protected static class ProductImpl implements Product
   {
      protected String code;
      protected String type;
      protected double price;
      protected String manufacturer;
      protected String description;

      public String getCode() { return code; }
      public String getType() { return type; }
      public double getPrice() { return price; }
      public String getManufacturer() { return manufacturer; }
      public String getDescription() { return description; }
   }
}
