/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.xmlsamples;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.xml.parsers.*;
import org.w3c.dom.*;
import org.xml.sax.*;

/**
* An extension of AbstractProductList that loads data from
* an XML DOM tree.
*/
public class DOMProductList extends AbstractProductList
{
   /**
   * DOM-specific implementation of loadProductList.
   */
   protected synchronized List loadProductList()
      throws IOException
   {
      List list = new ArrayList();
      try {

         // Use JAXP to parse the input stream
         // into a DOM tree

         DocumentBuilderFactory factory =
            DocumentBuilderFactory.newInstance();
         DocumentBuilder builder = factory.newDocumentBuilder();
         Document doc = builder.parse(inputURL);
         Element root = doc.getDocumentElement();

         // Extract the <product> elements, create Product
         // objects from them, and add them to the list.

         NodeList nodes = root.getElementsByTagName("product");

         for (int i = 0, n = nodes.getLength(); i < n; i++) {

            Element elemProduct = (Element) nodes.item(i);
            ProductImpl product = new ProductImpl();
            product.code = elemProduct.getAttribute("code");

            for ( Node node = elemProduct.getFirstChild();
                  node != null;
                  node = node.getNextSibling()) {

               if (node.getNodeType() == Node.ELEMENT_NODE) {

                  Element element = (Element) node;

                  String tagName = element.getNodeName();
                  String text = getElementText(element);

                  if (tagName.equals("product-type"))
                     product.type = text;

                  else if (tagName.equals("price"))
                     product.price = Double.parseDouble(text);

                  else if (tagName.equals("manufacturer"))
                     product.manufacturer = text;

                  else if (tagName.equals("description"))
                     product.description = text;
               }
            }

            list.add(product);
         }
      }
      catch (SAXException e) {
         throw new IOException
            ("parsing exception: " + e.getMessage());
      }
      catch (ParserConfigurationException e) {
         throw new IOException
            ("parsing exception: " + e.getMessage());
      }

      return list;
   }

   /**
   * Helper method that extracts the text of an element
   */
   private static String getElementText(Element element)
   {
      StringBuffer sb = new StringBuffer();

      for ( Node node = element.getFirstChild();
            node != null;
            node = node.getNextSibling()) {

         if (node.getNodeType() == Node.TEXT_NODE) {
            Text textNode = (Text) node;
            sb.append(textNode.getData());
         }
      }
      return sb.toString().trim();
   }
}
