/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.xmlsamples;

import java.io.*;
import java.net.*;
import java.util.*;
import javax.xml.parsers.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

/**
* An extension of AbstractProductList that loads data from
* a SAX event stream
*/
public class SAXProductList extends AbstractProductList
{
   /**
   * SAX-specific implementation of loadProductList.
   */
   protected synchronized List loadProductList()
      throws IOException
   {
      ProductContentHandler handler = new ProductContentHandler();
      try {
         SAXParserFactory spf = SAXParserFactory.newInstance();
         SAXParser parser = spf.newSAXParser();
         parser.parse(inputURL, handler);
      }
      catch (SAXException e) {
         throw new IOException
            ("parsing exception: " + e.getMessage());
      }
      catch (ParserConfigurationException e) {
         throw new IOException
            ("parsing exception: " + e.getMessage());
      }

      return handler.getProductList();
   }

   /**
   * Content handler that constructs the list of product objects
   */
   private static class ProductContentHandler
      extends DefaultHandler
   {
      private ProductImpl product;
      private List productList;
      private StringBuffer buffer;

      /**
      * Called when parsing starts
      */
      public void startDocument()
         throws SAXException
      {
         productList = new ArrayList();
         product = null;
         buffer = new StringBuffer();
      }

      /**
      * Called when a start tag is encountered
      */
      public void startElement
         (String ns, String ln, String qName, Attributes attrs)
            throws SAXException
      {
         if (qName.equals("product")) {
            product = new ProductImpl();
            product.code = attrs.getValue("code");
         }
         buffer.setLength(0);
      }

      /**
      * Accumulates characters from text nodes
      */
      public void characters(char[] ch, int start, int len)
         throws SAXException
      {
         buffer.append(ch, start, len);
      }

      /**
      * Called when an end tag is encountered
      */
      public void endElement(String ns, String ln, String qName)
         throws SAXException
      {
         String text = buffer.toString().trim();
         buffer.setLength(0);

         if (qName.equals("product-type"))
            product.type = text;
         else if (qName.equals("price"))
            product.price = Double.parseDouble(text);
         else if (qName.equals("manufacturer"))
            product.manufacturer = text;
         else if (qName.equals("description"))
            product.description = text;
         else if (qName.equals("product")) {
            productList.add(product);
         }
      }

      /**
      * Returns the constructed product list
      */
      public List getProductList()
      {
         return productList;
      }
   }
}
