/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import java.io.*;
import java.net.*;
import java.util.*;

/**
* A tag handler for a custom tag that keeps track
* of how long its body takes to execute.
*
* NOTE: This is *supposed* to fail.  It has a subtle
* bug (no package statement) that messes up most
* servlet containers.
*/
public class TimerTag extends TagSupport
{
   private long startTime;
   private long endTime;

   /**
   * Starts the timer
   */
   public int doStartTag() throws JspException
   {
      startTime = System.currentTimeMillis();
      return EVAL_BODY_INCLUDE;
   }

   /**
   * Stops the timer and calculates the elapsed time
   * in seconds. This is stored as a page context
   * attribute using the ID variable name
   */
   public int doEndTag() throws JspException
   {
      endTime = System.currentTimeMillis();
      double elapsed = (endTime - startTime)/1000.0;
      pageContext.setAttribute(getId(), new Double(elapsed));
      return EVAL_PAGE;
   }
}
