/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.debug.tracer;

import java.io.*;
import java.net.*;
import java.util.*;

/**
* Mainline for the HTTP tracer tool
*/
public class Main
{
   public static void main(String[] args) throws IOException
   {
      String opt_host = null;
      String opt_port = null;
      String opt_tracerPort = null;
      String opt_log = null;

      try {

         // Parse command line arguments

         for (int i = 0, n = args.length; i < n; i++) {
            String arg = args[i];
            if (arg.equals("-h")) {
               showUsage();
               return;
            }
            if (arg.equals("-host") && (i+1 < n))
               opt_host = args[++i];
            else if (arg.equals("-port") && (i+1 < n))
               opt_port = args[++i];
            else if (arg.equals("-tracerPort") && (i+1 < n))
               opt_tracerPort = args[++i];
            else if (arg.equals("-log") && (i+1 < n))
               opt_log = args[++i];
            else
               throw new IllegalArgumentException
               ("Unrecognized option " + arg);
         }

         // Verify that there is no port conflict

         int testTracerPort = (opt_tracerPort == null)
            ? Tracer.DEFAULT_PORT
            : Integer.parseInt(opt_tracerPort);

         int testHostPort = (opt_port == null)
            ? RequestHandler.DEFAULT_PORT
            : Integer.parseInt(opt_port);
         
         if (testTracerPort == testHostPort)
            throw new IllegalArgumentException
            ("Cannot assign port and tracerPort both to "
            + testHostPort);
      }
      catch (IllegalArgumentException e) {
         System.err.println(e.getMessage());
         return;
      }

      // Create the tracer and set its properties

      Tracer tracer = new Tracer();
      if (opt_host != null)
         tracer.setHost(opt_host);
      if (opt_port != null)
         tracer.setPort(Integer.parseInt(opt_port));
      if (opt_tracerPort != null)
         tracer.setTracerPort
            (Integer.parseInt(opt_tracerPort));
      if (opt_log != null)
         tracer.setLogWriter(new FileWriter(opt_log));

      // Start it running

      tracer.start();
   }

   public static final void showUsage()
   {
      String[] text = {
         "",
         "usage: java -jar tracer.jar [options]",
         "",
         "where options are:",
         "",
         "-host         <hostName>  (default is localhost)",
         "-port         <hostPort>  (default is 80)",
         "-tracerPort   <localPort> (default is 8601)",
         "-log          <fileName>  (default is stdout)",
      };
      for (int i = 0; i < text.length; i++)
         System.out.println(text[i]);
   }
}
