/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.debug.tracer;

import java.io.*;
import java.net.*;
import java.util.*;

/**
* Acts as a proxy web server, capturing requests
* and responses and echoing the headers to a
* log stream.
*/
public class Tracer extends Thread implements Logger
{
   public static final int DEFAULT_PORT = 8601;

   private String host;
   private int port;
   private int tracerPort;
   private PrintWriter logWriter;

   public void run()
   {
      // Set defaults if not otherwise specified

      if (tracerPort == 0)
         tracerPort = DEFAULT_PORT;

      if (logWriter == null)
         logWriter = new PrintWriter(System.out);

      // Start proxy server

      try {
         log("M: Opening tracer server on tracerPort "
            + tracerPort);
         ServerSocket server = new ServerSocket(tracerPort);

         // Loop forever

         while (true) {

            // Wait for connection

            log("M: Waiting for connections");
            Socket client = server.accept();
            log("M: Connection received from " + client);

            // Dispatch it to a request handler thread

            RequestHandler rh = new RequestHandler(client);
            rh.setLogger(this);
            if (host != null)
               rh.setHost(host);
            if (port != 0)
               rh.setPort(port);
            rh.start();
         }
      }
      catch (IOException e) {
         e.printStackTrace();
      }
   }

   // ===========================================
   //    Implementation of Logger
   // ===========================================

   /**
   * Writes a message to the log
   * @param message the message
   */
   public synchronized void log(String message)
   {
      logWriter.println(message);
      logWriter.flush();
   }

   // ===========================================
   //    Property setters
   // ===========================================

   /**
   * Sets the host.
   * @param host the host.
   */
   public void setHost(String host)
   {
      this.host = host;
   }

   /**
   * Sets the port.
   * @param port the port.
   */
   public void setPort(int port)
   {
      this.port = port;
   }

   /**
   * Sets the tracerPort.
   * @param tracerPort the tracerPort.
   */
   public void setTracerPort(int tracerPort)
   {
      this.tracerPort = tracerPort;
   }

   /**
   * Sets the logWriter.
   * @param logWriter the logWriter.
   */
   public void setLogWriter(Writer logWriter)
      throws IOException
   {
      this.logWriter = new PrintWriter(logWriter);
   }
}
