/**
*  Copyright (c) 2002 by Phil Hanna
*  All rights reserved.
*  
*  You may study, use, modify, and distribute this
*  software for any purpose provided that this
*  copyright notice appears in all copies.
*  
*  This software is provided without warranty
*  either expressed or implied.
*/
package com.jspcr.debug.webclient;

import java.io.*;
import java.net.*;
import java.util.*;

/**
* Mainline for running the Web client
*/
public class Main
{
   /**
   * Reads command line parameters, creates a new
   * <code>WebClient</code> object, then invokes it.
   */
   public static void main(String[] args)
      throws IOException
   {
      // Default values

      String host = "localhost";
      int port = 80;

      // Use values from command line, if specified

      for (int i = 0; i < args.length; i++) {
         String arg = args[i];
         if (arg.equals("-h") || arg.equals("-help")) {
            showUsage();
            return;
         }
         else
         if (arg.equals("-host") && ++i < args.length)
            host = args[i];
         else
         if (arg.equals("-port") && ++i < args.length)
            port = Integer.parseInt(args[i]);
      }

      // Create and start the Web client

      new WebClient(host, port).run();
   }

   /**
   * Displays the calling syntax
   */
   private static void showUsage()
   {
      String[] text = {
         "usage: java com.jspcr.debug.webclient.Main"
         + " [-host <hostName>]"
         + " [-port <portNumber>]",
      };
      for (int i = 0; i < text.length; i++)
         System.out.println(text[i]);
   }
}
