DROP DATABASE IF EXISTS usda15;
CREATE DATABASE usda15;
USE usda15;

/* Food Description */

DROP TABLE IF EXISTS FOOD_DES;
CREATE TABLE FOOD_DES (
   NDB_NO              CHAR(5) NOT NULL,
   FDGRP_CD            CHAR(4) NOT NULL,
   DESCR               CHAR(200) NOT NULL,
   SHRT_DESC           CHAR(60) NOT NULL,
   COMNAME             CHAR(100),
   MANUFACNAME         CHAR(50),
   SURVEY              CHAR(1),
   REF_DESC            CHAR(45),
   REFUSE              INTEGER,
   SCINAME             CHAR(60),
   N_FACTOR            DECIMAL(4,2),
   PRO_FACTOR          DECIMAL(4,2),
   FAT_FACTOR          DECIMAL(4,2),
   CHO_FACTOR          DECIMAL(4,2)
);
CREATE INDEX FOOD_DES1 ON FOOD_DES (NDB_NO);

/* Nutrient Data */

DROP TABLE IF EXISTS NUT_DATA;
CREATE TABLE NUT_DATA (
   NDB_NO              CHAR(5) NOT NULL,
   NUTR_NO             CHAR(3) NOT NULL,
   NUTR_VAL            DECIMAL(10,3) NOT NULL,
   NUM_DATA_PTS        INTEGER NOT NULL,
   STD_ERROR           DECIMAL(8,3),
   SRC_CD              CHAR(2) NOT NULL,
   DERIV_CD            CHAR(4),
   REF_NDB_NO          CHAR(5),
   ADD_NUTR_MARK       CHAR(1),
   NUM_STUDIES         INTEGER,
   MIN                 DECIMAL(10,3),
   MAX                 DECIMAL(10,3),
   DF                  INTEGER,
   LOW_EB              DECIMAL(10,3),
   UP_EB               DECIMAL(10,3),
   STAT_CMT            CHAR(10),
   CC                  CHAR(1),
   DATASRC_ID          CHAR(41)
);
CREATE INDEX NUT_DATA1 ON NUT_DATA (NDB_NO);
CREATE INDEX NUT_DATA2 ON NUT_DATA (NUTR_NO);

/* Gram Weights */

DROP TABLE IF EXISTS WEIGHT;
CREATE TABLE WEIGHT (
   NDB_NO              CHAR(5) NOT NULL,
   SEQ                 INTEGER NOT NULL,
   AMOUNT              DECIMAL(5,3) NOT NULL,
   MSRE_DESC           CHAR(80) NOT NULL,
   GM_WGT              DECIMAL(7,1) NOT NULL,
   NUM_DATA_PTS        INTEGER,
   STD_DEV             DECIMAL(7,3)
);
CREATE INDEX WEIGHT1 ON WEIGHT (NDB_NO);
CREATE INDEX WEIGHT2 ON WEIGHT (SEQ);

/* Footnote */

DROP TABLE IF EXISTS FOOTNOTE;
CREATE TABLE FOOTNOTE (
   NDB_NO              CHAR(5) NOT NULL,
   FOOTNT_NO           CHAR(4) NOT NULL,
   FOOTNT_TYP          CHAR(1) NOT NULL,
   NUTR_NO             CHAR(3),
   FOOTNT_TXT          CHAR(200) NOT NULL
);
CREATE INDEX FOOTNOTE1 ON FOOTNOTE (NDB_NO);
CREATE INDEX FOOTNOTE2 ON FOOTNOTE (FOOTNT_NO);

/* Food Group Description */

DROP TABLE IF EXISTS FD_GROUP;
CREATE TABLE FD_GROUP (
   FDGRP_CD            CHAR(4) NOT NULL,
   FDGRP_DESC          CHAR(60) NOT NULL
);
CREATE INDEX FD_GROUP1 ON FD_GROUP (FDGRP_CD);

/* Nutrient Definition */

DROP TABLE IF EXISTS NUTR_DEF;
CREATE TABLE NUTR_DEF (
   NUTR_NO             CHAR(3) NOT NULL,
   UNITS               CHAR(7) NOT NULL,
   TAGNAME             CHAR(20) NOT NULL,
   NUTRDESC            CHAR(60) NOT NULL,
   DECIMALS            CHAR(1) NOT NULL
);
CREATE INDEX NUTR_DEF1 ON NUTR_DEF (NUTR_NO);

/* Source Code */

DROP TABLE IF EXISTS SRC_CD;
CREATE TABLE SRC_CD (
   SRC_CD              CHAR(2) NOT NULL,
   SRCCD_DESC          CHAR(60) NOT NULL
);
CREATE INDEX SRC_CD1 ON SRC_CD (SRC_CD);

/* Data Derivation Description */

DROP TABLE IF EXISTS DERIV_CD;
CREATE TABLE DERIV_CD (
   DERIV_CD            CHAR(4) NOT NULL,
   DERIV_DESC          CHAR(120) NOT NULL
);
CREATE INDEX DERIV_CD1 ON DERIV_CD (DERIV_CD);

/* Sources of Data */

DROP TABLE IF EXISTS DATA_SRC;
CREATE TABLE DATA_SRC (
   DATASRC_ID          CHAR(6) NOT NULL,
   AUTHORS             CHAR(255) NOT NULL,
   TITLE               CHAR(255) NOT NULL,
   YEAR                CHAR(4) NOT NULL,
   JOURNAL             CHAR(135),
   VOL_CITY            CHAR(10),
   ISSUE_STATE         CHAR(5),
   START_PAGE          CHAR(5),
   END_PAGE            CHAR(5)
);
CREATE INDEX DATA_SRC1 ON DATA_SRC (DATASRC_ID);
